@@ -1,8 +1,11 @@
 from django.db import models
 from django.utils.translation import pgettext_lazy
+from wcd_geo_db.modules.code_seeker.models import (
+    CodesDefinableMixin, codes_mixin_indexes
+)
 
 from .mixins import (
-    CodesDefinableMixin, GroupingMixin, NamedMixin,
+    GroupingMixin, NamedMixin,
     create_division_field, create_types_field
 )
 from .geometry import WithGeometryMixin
